@@ -15,7 +15,8 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Module for aws data generators."""
-from nise.generators.aws.aws_generator import AWSGenerator, AWS_COLUMNS  # noqa: F401
+from nise.generators.aws.aws_generator import AWS_COLUMNS  # noqa: F401
+from nise.generators.aws.aws_generator import AWSGenerator  # noqa: F401
 from nise.generators.aws.data_transfer_generator import DataTransferGenerator  # noqa: F401
 from nise.generators.aws.ebs_generator import EBSGenerator  # noqa: F401
 from nise.generators.aws.ec2_generator import EC2Generator  # noqa: F401
